@@ -15,7 +15,7 @@ Launcher::Launcher(MainWindow *main)
 	m_buttons[METHER_BUTTON] = new QPushButton(tr("Manage\nUsb"));
 	m_buttons[XTERM_BUTTON] = new QPushButton(tr("Developer\nXTerm"));
 
-	m_buttons[XTERM_BUTTON]->setEnabled(false);
+	//m_buttons[XTERM_BUTTON]->setEnabled(false);
 	m_layout->addWidget(m_buttons[PASSWD_BUTTON]);
 	m_layout->addWidget(m_buttons[METHER_BUTTON]);
 	m_layout->addWidget(m_buttons[XTERM_BUTTON]);
@@ -33,7 +33,8 @@ Launcher::startXTerm(void)
 {
 	QProcess *xterm = new QProcess;
 
-	xterm->startDetached(QString("osso-xterm"));
+	xterm->startDetached(QString("./xterm.sh"));
+	//xterm->start(QString("./xterm.sh", (QStringList)0);
 
 	delete xterm;
 }
